mindroot.coreplugins.jwt\_auth package
======================================

Submodules
----------

mindroot.coreplugins.jwt\_auth.middleware module
------------------------------------------------

.. automodule:: mindroot.coreplugins.jwt_auth.middleware
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.jwt\_auth.mod module
-----------------------------------------

.. automodule:: mindroot.coreplugins.jwt_auth.mod
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.jwt\_auth.role\_checks module
--------------------------------------------------

.. automodule:: mindroot.coreplugins.jwt_auth.role_checks
   :members:
   :show-inheritance:
   :undoc-members:

mindroot.coreplugins.jwt\_auth.router module
--------------------------------------------

.. automodule:: mindroot.coreplugins.jwt_auth.router
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: mindroot.coreplugins.jwt_auth
   :members:
   :show-inheritance:
   :undoc-members:
